==============================
ouimeaux
==============================

.. image:: https://badge.fury.io/py/ouimeaux.png
    :target: http://badge.fury.io/py/ouimeaux
    
.. image:: https://travis-ci.org/iancmcc/ouimeaux.png?branch=develop
        :target: https://travis-ci.org/iancmcc/ouimeaux

.. image:: https://pypip.in/d/ouimeaux/badge.png
        :target: https://crate.io/packages/ouimeaux?version=latest


Open source control for Belkin WeMo devices

* Free software: BSD license
* Documentation: http://ouimeaux.rtfd.org.

Features
--------

* Supports WeMo Switch, Light Switch, Insight Switch and Motion
* Command-line tool to discover and control devices in your environment
* REST API to obtain information and perform actions on devices
* Simple responsive Web app provides device control on mobile
* Python API to interact with device at a low level
